==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-serializers-json/src/test/java/org/apache/streampipes/serializers/json/TestJacksonSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.serializers.json;

import org.apache.streampipes.model.template.PipelineElementTemplate;
import org.apache.streampipes.test.generator.template.PipelineElementTemplateHelpers;

import com.fasterxml.jackson.core.JsonProcessingException;
import org.junit.Assert;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class TestJacksonSerializer {

  public static void assertions(PipelineElementTemplate template) {
    Assert.assertEquals("name", template.getTemplateName());
    Assert.assertEquals("description", template.getTemplateDescription());
    Assert.assertEquals(2, template.getTemplateConfigs().size());
    Assert.assertEquals("test-string", template.getTemplateConfigs().get("test-key").getValue());
    Assert.assertTrue(template.getTemplateConfigs().get("test-key").isEditable());
    Assert.assertTrue(template.getTemplateConfigs().get("test-key").isDisplayed());
    Assert.assertTrue(template.getTemplateConfigs().get("test-key-2").isEditable());
    Assert.assertFalse(template.getTemplateConfigs().get("test-key-2").isDisplayed());
  }

  @Test
  public void testPipelineElementTemplateSerialization() {
    PipelineElementTemplate template = PipelineElementTemplateHelpers.makePipelineElementTemplate();

    try {
      String json = JacksonSerializer.getObjectMapper().writeValueAsString(template);
      PipelineElementTemplate template2 =
          JacksonSerializer.getObjectMapper().readValue(json, PipelineElementTemplate.class);
      assertions(template2);
      assertEquals(2, template2.getTemplateConfigs().get("test-key-2").getValue());
    } catch (JsonProcessingException e) {
      e.printStackTrace();
    }
  }
}

==> apache-streampipes-0.95.1-source-release.zip: apache-streampipes-0.95.1/streampipes-serializers-json/src/test/java/org/apache/streampipes/serializers/json/TestJacksonSerializer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.serializers.json;

import org.apache.streampipes.model.template.PipelineElementTemplate;
import org.apache.streampipes.test.generator.template.PipelineElementTemplateHelpers;

import com.fasterxml.jackson.core.JsonProcessingException;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class TestJacksonSerializer {

  public static void assertions(PipelineElementTemplate template) {
    Assertions.assertEquals("name", template.getTemplateName());
    Assertions.assertEquals("description", template.getTemplateDescription());
    Assertions.assertEquals(2,
                            template.getTemplateConfigs().size());
    Assertions.assertEquals("test-string",
                            template.getTemplateConfigs().get("test-key").getValue());
    Assertions.assertTrue(template.getTemplateConfigs().get("test-key").isEditable());
    Assertions.assertTrue(template.getTemplateConfigs().get("test-key").isDisplayed());
    Assertions.assertTrue(template.getTemplateConfigs().get("test-key-2").isEditable());
    Assertions.assertFalse(template.getTemplateConfigs().get("test-key-2").isDisplayed());
  }

  @Test
  public void testPipelineElementTemplateSerialization() {
    PipelineElementTemplate template = PipelineElementTemplateHelpers.makePipelineElementTemplate();

    try {
      String json = JacksonSerializer.getObjectMapper().writeValueAsString(template);
      PipelineElementTemplate template2 =
          JacksonSerializer.getObjectMapper().readValue(json, PipelineElementTemplate.class);
      assertions(template2);
      Assertions.assertEquals(2,
                              template2.getTemplateConfigs().get("test-key-2").getValue());
    } catch (JsonProcessingException e) {
      e.printStackTrace();
    }
  }
}
